pub(crate) fn poll_tray_events(tray: &TrayState) -> TrayActionExpand description
Poll for tray icon clicks and menu selections without blocking.
pub(crate) fn poll_tray_events(tray: &TrayState) -> TrayActionPoll for tray icon clicks and menu selections without blocking.